@@ -33,6 +33,7 @@ class Exceptions:
     AuthException: Type[BotocoreClientError]
     ClientError: Type[BotocoreClientError]
     EC2InstanceNotFoundException: Type[BotocoreClientError]
+    EC2InstanceStateInvalidException: Type[BotocoreClientError]
     EC2InstanceTypeInvalidException: Type[BotocoreClientError]
     InvalidArgsException: Type[BotocoreClientError]
     SerialConsoleAccessDisabledException: Type[BotocoreClientError]
@@ -44,7 +45,7 @@ class Exceptions:
 
 class EC2InstanceConnectClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/ec2-instance-connect.html#EC2InstanceConnect.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.39/reference/services/ec2-instance-connect.html#EC2InstanceConnect.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2_instance_connect/client.html)
     """
 
@@ -60,7 +61,7 @@ class EC2InstanceConnectClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/ec2-instance-connect.html#EC2InstanceConnect.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.39/reference/services/ec2-instance-connect.html#EC2InstanceConnect.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2_instance_connect/client.html#can_paginate)
         """
 
@@ -74,7 +75,7 @@ class EC2InstanceConnectClient(BaseClient):
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/ec2-instance-connect.html#EC2InstanceConnect.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.39/reference/services/ec2-instance-connect.html#EC2InstanceConnect.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2_instance_connect/client.html#generate_presigned_url)
         """
 
@@ -84,17 +85,22 @@ class EC2InstanceConnectClient(BaseClient):
         """
         Pushes an SSH public key to the specified EC2 instance.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/ec2-instance-connect.html#EC2InstanceConnect.Client.send_serial_console_ssh_public_key)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.39/reference/services/ec2-instance-connect.html#EC2InstanceConnect.Client.send_serial_console_ssh_public_key)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2_instance_connect/client.html#send_serial_console_ssh_public_key)
         """
 
     def send_ssh_public_key(
-        self, *, InstanceId: str, InstanceOSUser: str, SSHPublicKey: str, AvailabilityZone: str
+        self,
+        *,
+        InstanceId: str,
+        InstanceOSUser: str,
+        SSHPublicKey: str,
+        AvailabilityZone: str = ...
     ) -> SendSSHPublicKeyResponseTypeDef:
         """
         Pushes an SSH public key to the specified EC2 instance for use by the specified
         user.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/ec2-instance-connect.html#EC2InstanceConnect.Client.send_ssh_public_key)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.39/reference/services/ec2-instance-connect.html#EC2InstanceConnect.Client.send_ssh_public_key)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2_instance_connect/client.html#send_ssh_public_key)
         """
