@@ -1,7 +1,7 @@
 """
 Type annotations for ec2-instance-connect service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2_instance_connect/type_defs/)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2_instance_connect/type_defs.html)
 
 Usage::
 
@@ -14,8 +14,6 @@ Usage::
 import sys
 from typing import Dict
 
-from typing_extensions import NotRequired
-
 if sys.version_info >= (3, 9):
     from typing import TypedDict
 else:
@@ -41,15 +39,28 @@ ResponseMetadataTypeDef = TypedDict(
     },
 )
 
-SendSSHPublicKeyRequestRequestTypeDef = TypedDict(
-    "SendSSHPublicKeyRequestRequestTypeDef",
+_RequiredSendSSHPublicKeyRequestRequestTypeDef = TypedDict(
+    "_RequiredSendSSHPublicKeyRequestRequestTypeDef",
     {
         "InstanceId": str,
         "InstanceOSUser": str,
         "SSHPublicKey": str,
-        "AvailabilityZone": str,
     },
 )
+_OptionalSendSSHPublicKeyRequestRequestTypeDef = TypedDict(
+    "_OptionalSendSSHPublicKeyRequestRequestTypeDef",
+    {
+        "AvailabilityZone": str,
+    },
+    total=False,
+)
+
+
+class SendSSHPublicKeyRequestRequestTypeDef(
+    _RequiredSendSSHPublicKeyRequestRequestTypeDef, _OptionalSendSSHPublicKeyRequestRequestTypeDef
+):
+    pass
+
 
 SendSSHPublicKeyResponseTypeDef = TypedDict(
     "SendSSHPublicKeyResponseTypeDef",
